@@ -32,18 +32,14 @@
 #include <openbabel/mol.h>
 #include <openbabel/forcefield.h>
 
-#include <QGLWidget>
-#include <QObject>
-#include <QStringList>
-#include <QImage>
-#include <QAction>
-#include <QWidget>
-#include <QPushButton>
-#include <QComboBox>
-#include <QCheckBox>
-#include <QSpinBox>
-#include <QUndoStack>
-#include <QMutex>
+#include <QtCore/QMutex>
+#include <QtCore/QThread>
+#include <QtGui/QAction>
+#include <QtGui/QPushButton>
+#include <QtGui/QComboBox>
+#include <QtGui/QCheckBox>
+#include <QtGui/QSpinBox>
+#include <QtGui/QUndoStack>
 
 namespace Avogadro {
 
@@ -55,7 +51,7 @@ namespace Avogadro {
       AutoOptThread(QObject *parent=0);
 
       void setup(Molecule *molecule, OpenBabel::OBForceField* forceField,
-          int algorithm, /* int convergence, */ int steps);
+                 int algorithm, /* int convergence, */ int steps);
 
       void run();
       void update();
@@ -109,6 +105,7 @@ namespace Avogadro {
       virtual QUndoCommand* mousePressEvent(GLWidget *widget, QMouseEvent *event);
       virtual QUndoCommand* mouseReleaseEvent(GLWidget *widget, QMouseEvent *event);
       virtual QUndoCommand* mouseMoveEvent(GLWidget *widget, QMouseEvent *event);
+      virtual QUndoCommand* mouseDoubleClickEvent(GLWidget *widget, QMouseEvent *event);
       virtual QUndoCommand* wheelEvent(GLWidget *widget, QWheelEvent *event);
 
       virtual int usefulness() const;
